lambeq.backend
==============

lambeq.backend.grammar
----------------------

.. automodule:: lambeq.backend.grammar
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.backend.tensor
---------------------

.. automodule:: lambeq.backend.tensor
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.backend.quantum
----------------------

.. automodule:: lambeq.backend.quantum
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.backend.numerical_backend
--------------------------------

.. automodule:: lambeq.backend.numerical_backend
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.backend.tk
-----------------

.. automodule:: lambeq.backend.tk
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.backend.pennylane
------------------------

.. automodule:: lambeq.backend.pennylane
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.backend.drawing
----------------------

.. automodule:: lambeq.backend.drawing
   :members:
   :undoc-members:
   :show-inheritance:
